CREATE SEQUENCE seq;

CREATE TABLE member (
    member_id              bigint PRIMARY KEY,
    username               varchar NOT NULL,
    member_number          varchar,

    -- UNIQUE(username, member_number) doesn't work well with NULLs. It allows to insert multiple records like ("somename", NULL).
    username$member_number array AS (username, member_number) UNIQUE
);

DELETE FROM mail
WHERE userid IS NULL OR length(userid) = 0;

INSERT INTO member (member_id, username, member_number)
    SELECT
        nextval('seq'),
        *,
        NULL
    FROM
        (SELECT DISTINCT userid
         FROM mail);

ALTER TABLE mail RENAME TO mail_temp;

CREATE TABLE mail (
    mail_id      bigint PRIMARY KEY,
    member_id    bigint NOT NULL REFERENCES member,
    trnuid       varchar,
    fmtdtcreated varchar,
    dtdtcreated  bigint,
    mail_from    varchar,
    mail_to      varchar,
    subject      varchar,
    body         varchar,
    incimages    boolean,
    usehtml      boolean,
    read         boolean,
    deleted      boolean
);

INSERT INTO mail (mail_id, member_id, trnuid, fmtdtcreated, dtdtcreated, mail_from, mail_to, subject, body, incimages, usehtml, read, deleted)
    SELECT
        nextval('seq'),
        (SELECT member_id
         FROM member
         WHERE username = userid),
        trnuid,
        fmtdtcreated,
        dtdtcreated,
        key_from,
        to,
        subject,
        msgbody,
        incimages,
        usehtml,
        is_read,
        is_deleted
    FROM mail_temp;

DROP TABLE mail_temp;
